@@ -1,6 +1,5 @@
 # flake8: NOQA E5
 import inspect
-import os
 import sys
 from os.path import dirname, relpath
 from pathlib import Path
@@ -10,7 +9,7 @@ import libtmux  # NOQA
 from libtmux import test  # NOQA
 
 # Get the project root dir, which is the parent dir of this
-cwd = Path.cwd()
+cwd = Path(__file__).parent
 project_root = cwd.parent
 
 sys.path.insert(0, str(project_root))
@@ -18,7 +17,7 @@ sys.path.insert(0, str(cwd / "_ext"))
 
 # package data
 about: Dict[str, str] = {}
-with open("../libtmux/__about__.py") as fp:
+with open(project_root / "libtmux" / "__about__.py") as fp:
     exec(fp.read(), about)
 
 extensions = [
