@@ -6,24 +6,50 @@ libtmux.pane
 
 """
 import logging
+import typing as t
+from typing import overload
+
+from libtmux.common import tmux_cmd
 
 from . import exc
-from .common import TmuxMappingObject, TmuxRelationalObject
+from .common import PaneDict, TmuxMappingObject, TmuxRelationalObject
+
+if t.TYPE_CHECKING:
+    from typing_extensions import Literal
+
+    from .server import Server
+    from .session import Session
+    from .window import Window
+
 
 logger = logging.getLogger(__name__)
 
 
-class Pane(TmuxMappingObject, TmuxRelationalObject):
+class Pane(TmuxMappingObject):
     """
-    A :term:`tmux(1)` :term:`Pane` [#]_.
+    A :term:`tmux(1)` :term:`Pane` [pane_manual]_.
 
     ``Pane`` instances can send commands directly to a pane, or traverse
     between linked tmux objects.
 
-    Parameters
+    Attributes
     ----------
     window : :class:`Window`
 
+    Examples
+    --------
+    >>> pane
+    Pane(%1 Window(@1 ...:..., Session($1 ...)))
+
+    >>> pane in window.panes
+    True
+
+    >>> pane.window
+    Window(@1 ...:..., Session($1 ...))
+
+    >>> pane.session
+    Session($1 ...)
+
     Notes
     -----
 
@@ -33,7 +59,7 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
     References
     ----------
 
-    .. [#] tmux pane. openbsd manpage for TMUX(1).
+    .. [pane_manual] tmux pane. openbsd manpage for TMUX(1).
            "Each window displayed by tmux may be split into one or more
            panes; each pane takes up a certain area of the display and is
            a separate terminal."
@@ -42,39 +68,48 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
        Accessed April 1st, 2018.
     """
 
-    #: namespace used :class:`~libtmux.common.TmuxMappingObject`
-    formatter_prefix = 'pane_'
-
-    def __init__(self, window=None, **kwargs):
-        if not window:
-            raise ValueError('Pane must have ``Window`` object')
+    formatter_prefix = "pane_"
+    """Namespace used for :class:`~libtmux.common.TmuxMappingObject`"""
+    window: "Window"
+    """:class:`libtmux.Window` pane is linked to"""
+    session: "Session"
+    """:class:`libtmux.Session` pane is linked to"""
+    server: "Server"
+    """:class:`libtmux.Server` pane is linked to"""
 
+    def __init__(
+        self,
+        window: "Window",
+        pane_id: t.Union[str, int],
+        **kwargs: t.Any,
+    ) -> None:
         self.window = window
         self.session = self.window.session
         self.server = self.session.server
 
-        self._pane_id = kwargs['pane_id']
+        self._pane_id = pane_id
 
         self.server._update_panes()
 
     @property
-    def _info(self, *args):
-
-        attrs = {'pane_id': self._pane_id}
+    def _info(self) -> PaneDict:  # type: ignore  # mypy#1362
+        attrs = {"pane_id": self._pane_id}
 
         # from https://github.com/serkanyersen/underscore.py
-        def by(val, *args):
-            for key, value in attrs.items():
+        def by(val: PaneDict) -> bool:
+            for key in attrs.keys():
                 try:
                     if attrs[key] != val[key]:
                         return False
                 except KeyError:
                     return False
-                return True
+            return True
 
-        return list(filter(by, self.server._panes))[0]
+        target_panes = [s for s in self.server._panes if by(s)]
 
-    def cmd(self, cmd, *args, **kwargs):
+        return target_panes[0]
+
+    def cmd(self, cmd: str, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
         """Return :meth:`Server.cmd` defaulting to ``target_pane`` as target.
 
         Send command to tmux with :attr:`pane_id` as ``target-pane``.
@@ -86,14 +121,19 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
         -------
         :class:`Server.cmd`
         """
-        if not any(arg.startswith('-t') for arg in args):
-            args = ('-t', self.get('pane_id')) + args
+        if not any(arg.startswith("-t") for arg in args):
+            args = ("-t", self.get("pane_id")) + args
 
         return self.server.cmd(cmd, *args, **kwargs)
 
-    def send_keys(self, cmd, enter=True, suppress_history=True, literal=False):
-        """
-        ``$ tmux send-keys`` to the pane.
+    def send_keys(
+        self,
+        cmd: str,
+        enter: t.Optional[bool] = True,
+        suppress_history: t.Optional[bool] = False,
+        literal: t.Optional[bool] = False,
+    ) -> None:
+        r"""``$ tmux send-keys`` to the pane.
 
         A leading space character is added to cmd to avoid polluting the
         user's history.
@@ -105,21 +145,53 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
         enter : bool, optional
             Send enter after sending the input, default True.
         suppress_history : bool, optional
-            Don't add these keys to the shell history, default True.
+            Prepend a space to command to suppress shell history, default False.
+
+            .. versionchanged:: 0.14
+
+               Default changed from True to False.
         literal : bool, optional
             Send keys literally, default True.
+
+        Examples
+        --------
+        >>> pane = window.split_window(shell='sh')
+        >>> pane.capture_pane()
+        ['$']
+
+        >>> pane.send_keys('echo "Hello world"', enter=True)
+
+        >>> pane.capture_pane()
+        ['$ echo "Hello world"', 'Hello world', '$']
+
+        >>> print('\n'.join(pane.capture_pane()))  # doctest: +NORMALIZE_WHITESPACE
+        $ echo "Hello world"
+        Hello world
+        $
         """
-        prefix = ' ' if suppress_history else ''
+        prefix = " " if suppress_history else ""
 
         if literal:
-            self.cmd('send-keys', '-l', prefix + cmd)
+            self.cmd("send-keys", "-l", prefix + cmd)
         else:
-            self.cmd('send-keys', prefix + cmd)
+            self.cmd("send-keys", prefix + cmd)
 
         if enter:
             self.enter()
 
-    def display_message(self, cmd, get_text=False):
+    @overload
+    def display_message(
+        self, cmd: str, get_text: "Literal[True]"
+    ) -> t.Union[str, t.List[str]]:
+        ...
+
+    @overload
+    def display_message(self, cmd: str, get_text: "Literal[False]") -> None:
+        ...
+
+    def display_message(
+        self, cmd: str, get_text: bool = False
+    ) -> t.Optional[t.Union[str, t.List[str]]]:
         """
         ``$ tmux display-message`` to the pane.
 
@@ -139,22 +211,27 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
         :class:`None`
         """
         if get_text:
-            return self.cmd('display-message', '-p', cmd).stdout
-        else:
-            self.cmd('display-message', cmd)
+            return self.cmd("display-message", "-p", cmd).stdout
 
-    def clear(self):
+        self.cmd("display-message", cmd)
+        return None
+
+    def clear(self) -> None:
         """Clear pane."""
-        self.send_keys('reset')
+        self.send_keys("reset")
 
-    def reset(self):
+    def reset(self) -> None:
         """Reset and clear pane history."""
 
-        self.cmd('send-keys', r'-R \; clear-history')
+        self.cmd("send-keys", r"-R \; clear-history")
 
     def split_window(
-        self, attach=False, vertical=True, start_directory=None, percent=None
-    ):
+        self,
+        attach: bool = False,
+        vertical: bool = True,
+        start_directory: t.Optional[str] = None,
+        percent: t.Optional[int] = None,
+    ) -> "Pane":
         """
         Split window at pane and return newly created :class:`Pane`.
 
@@ -174,14 +251,14 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
         :class:`Pane`
         """
         return self.window.split_window(
-            target=self.get('pane_id'),
+            target=self.get("pane_id"),
             start_directory=start_directory,
             attach=attach,
             vertical=vertical,
             percent=percent,
         )
 
-    def set_width(self, width):
+    def set_width(self, width: int) -> None:
         """
         Set width of pane.
 
@@ -192,7 +269,7 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
         """
         self.resize_pane(width=width)
 
-    def set_height(self, height):
+    def set_height(self, height: int) -> None:
         """
         Set height of pane.
 
@@ -203,7 +280,7 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
         """
         self.resize_pane(height=height)
 
-    def resize_pane(self, *args, **kwargs):
+    def resize_pane(self, *args: t.Any, **kwargs: t.Any) -> "Pane":
         """
         ``$ tmux resize-pane`` of pane and return ``self``.
 
@@ -227,13 +304,12 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
         ------
         exc.LibTmuxException
         """
-
-        if 'height' in kwargs:
-            proc = self.cmd('resize-pane', '-y%s' % int(kwargs['height']))
-        elif 'width' in kwargs:
-            proc = self.cmd('resize-pane', '-x%s' % int(kwargs['width']))
+        if "height" in kwargs:
+            proc = self.cmd("resize-pane", "-y%s" % int(kwargs["height"]))
+        elif "width" in kwargs:
+            proc = self.cmd("resize-pane", "-x%s" % int(kwargs["width"]))
         else:
-            proc = self.cmd('resize-pane', args[0])
+            proc = self.cmd("resize-pane", args[0])
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
@@ -241,15 +317,15 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
         self.server._update_panes()
         return self
 
-    def enter(self):
+    def enter(self) -> None:
         """
         Send carriage return to pane.
 
         ``$ tmux send-keys`` send Enter to the pane.
         """
-        self.cmd('send-keys', 'Enter')
+        self.cmd("send-keys", "Enter")
 
-    def capture_pane(self):
+    def capture_pane(self) -> t.Union[str, t.List[str]]:
         """
         Capture text from pane.
 
@@ -259,9 +335,9 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
         -------
         :class:`list`
         """
-        return self.cmd('capture-pane', '-p').stdout
+        return self.cmd("capture-pane", "-p").stdout
 
-    def select_pane(self):
+    def select_pane(self) -> "Pane":
         """
         Select pane. Return ``self``.
 
@@ -273,7 +349,12 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
         -------
         :class:`pane`
         """
-        return self.window.select_pane(self.get('pane_id'))
+        pane = self.window.select_pane(self._pane_id)
+        if pane is None:
+            raise exc.LibTmuxException(f"Pane not found: {self}")
+        return pane
 
-    def __repr__(self):
-        return "%s(%s %s)" % (self.__class__.__name__, self.get('pane_id'), self.window)
+    def __repr__(self) -> str:
+        return "{}({} {})".format(
+            self.__class__.__name__, self.get("pane_id"), self.window
+        )
