@@ -47,6 +47,23 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
     config_file : str, optional
     colors : str, optional
 
+    Examples
+    --------
+    >>> server
+    <libtmux.server.Server object at ...>
+
+    >>> server.sessions
+    [Session($1 ...)]
+
+    >>> server.sessions[0].windows
+    [Window(@1 ...:..., Session($1 ...)]
+
+    >>> server.sessions[0].attached_window
+    Window(@1 ...:..., Session($1 ...)
+
+    >>> server.sessions[0].attached_pane
+    Pane(%1 Window(@1 ...:..., Session($1 ...)))
+
     References
     ----------
     .. [server_manual] CLIENTS AND SESSIONS. openbsd manpage for TMUX(1)
@@ -518,15 +535,17 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
         ------
         :exc:`exc.BadSessionName`
         """
-        session_check_name(session_name)
-        assert session_name is not None
+        if session_name is not None:
+            session_check_name(session_name)
 
-        if self.has_session(session_name):
-            if kill_session:
-                self.cmd("kill-session", "-t%s" % session_name)
-                logger.info("session %s exists. killed it." % session_name)
-            else:
-                raise exc.TmuxSessionExists("Session named %s exists" % session_name)
+            if self.has_session(session_name):
+                if kill_session:
+                    self.cmd("kill-session", "-t%s" % session_name)
+                    logger.info("session %s exists. killed it." % session_name)
+                else:
+                    raise exc.TmuxSessionExists(
+                        "Session named %s exists" % session_name
+                    )
 
         logger.debug("creating session %s" % session_name)
 
